API docs for “spamfighter.core.commands.partner.PartnerAuthInfo”

# Class s.c.c.p.PartnerAuthInfo(object):

Part of spamfighter.core.commands.partner View Source View In Hierarchy

Класс, хранящий информации об авторизации партнера.

Instance Variables | info | инорфмация об авторизации (произвольного типа)

Method | __init__ | Конструктор.
Method | serialize | Сериализация.
Class Method | unserialize | Десериализация.

def __init__(self, info): (source)
Конструктор.

Parameters | info | инорфмация об авторизации (произвольного типа)

def serialize(self): (source)
Сериализация.

@classmethod
def unserialize(cls, serialized): (source)
Десериализация.